@@ -23,4 +23,9 @@ def register():
         module='payment_gateway_stripe', type_='model')
     Pool.register(
         transaction.AddPaymentProfile,
+        transaction.TransactionUseCard,
+        module='payment_gateway_stripe', type_='wizard')
+    Pool.register(
+        transaction.AddSalePayment,
+        depends=['sale_payment_gateway'],
         module='payment_gateway_stripe', type_='wizard')
